@@ -1,44 +1,42 @@
 if (require("testthat") && require("modelbased") && require("rstanarm") && require("insight")) {
   test_that("estimate_means", {
-    if (require("rstanarm")) {
-      data <- mtcars
-      data$gear <- as.factor(data$gear)
+    data <- mtcars
+    data$gear <- as.factor(data$gear)
 
-      model <- suppressWarnings(rstanarm::stan_glm(mpg ~ wt * gear, data = data, refresh = 0, iter = 200, chains = 2))
-      estim <- estimate_means(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
+    model <- suppressWarnings(rstanarm::stan_glm(mpg ~ wt * gear, data = data, refresh = 0, iter = 200, chains = 2))
+    estim <- estimate_means(model)
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
-      data$cyl <- as.factor(data$cyl)
-      model <- suppressWarnings(rstanarm::stan_glm(vs ~ cyl, data = data, refresh = 0, iter = 200, chains = 2))
-      estim <- estimate_means(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
+    data$cyl <- as.factor(data$cyl)
+    model <- suppressWarnings(rstanarm::stan_glm(vs ~ cyl, data = data, refresh = 0, iter = 200, chains = 2))
+    estim <- estimate_means(model)
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
 
 
-      data <- iris
-      data$Petal.Length_factor <- ifelse(data$Petal.Length < 4.2, "A", "B")
+    data <- iris
+    data$Petal.Length_factor <- ifelse(data$Petal.Length < 4.2, "A", "B")
 
-      model <- suppressWarnings(rstanarm::stan_glm(Sepal.Width ~ Species * Petal.Length_factor, data = data, refresh = 0, iter = 200, chains = 2))
-      estim <- estimate_means(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(6, 5))
+    model <- suppressWarnings(rstanarm::stan_glm(Sepal.Width ~ Species * Petal.Length_factor, data = data, refresh = 0, iter = 200, chains = 2))
+    estim <- estimate_means(model)
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(6, 5))
 
-      model <- suppressWarnings(rstanarm::stan_glm(Petal.Length ~ Sepal.Width + Species, data = iris, refresh = 0, iter = 200, chains = 2))
-      estim <- estimate_means(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
+    model <- suppressWarnings(rstanarm::stan_glm(Petal.Length ~ Sepal.Width + Species, data = iris, refresh = 0, iter = 200, chains = 2))
+    estim <- estimate_means(model)
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
 
-      estim <- estimate_means(model, modulate = "Sepal.Width")
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(30, 5))
+    estim <- estimate_means(model, modulate = "Sepal.Width")
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(30, 5))
 
-      df <- iris
-      df$y <- as.numeric(as.factor(ifelse(df$Sepal.Width > 3, "A", "B"))) - 1
-      model <- rstanarm::stan_glm(y ~ Species, family = "binomial", data = df, refresh = 0, iter = 200, chains = 2)
+    df <- iris
+    df$y <- as.numeric(as.factor(ifelse(df$Sepal.Width > 3, "A", "B"))) - 1
+    model <- rstanarm::stan_glm(y ~ Species, family = "binomial", data = df, refresh = 0, iter = 200, chains = 2)
 
-      estim <- estimate_means(model)
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
-      estim <- estimate_means(model, transform = "response")
-      testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
-      testthat::expect_true(all(estim$Probability >= 0) & all(estim$Probability <= 1))
-    }
+    estim <- estimate_means(model)
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
+    estim <- estimate_means(model, transform = "response")
+    testthat::expect_equal(c(nrow(estim), ncol(estim)), c(3, 4))
+    testthat::expect_true(all(estim$Probability >= 0) & all(estim$Probability <= 1))
 
 
     model <- lm(Petal.Length ~ Sepal.Width + Species, data = iris)
